@@ -9,15 +9,18 @@ jacobi.p.weight <- function( x, alpha, beta )
 ### alpha = the first polynomial parameter
 ### beta = the second polynomial parameter
 ###
+    if ( alpha < -1 )
+        stop( "argument alpha is less than -1" )
+    if ( beta < -1 )
+        stop( "argument beta is less than =1" )
+    if ( ( abs( alpha ) < 1e-6 ) & ( abs( beta ) < 1e-6 ) )
+        return( legendre.weight( x ) )
     n <- length( x )
     y <- rep( 0, n )
-    almost.legendre <- ( abs( alpha ) < 1e-6 ) & ( abs( beta ) < 1e-6 )
     for ( i in 1:n ) {
-        if ( ( x[i] > -1 ) && ( x[i] < +1 ) )
-            if ( almost.legendre )
-                y[i] <- 1
-            else
-                y[i] <- ( ( 1 - x[i] ) ^ alpha ) * ( ( 1 + x[i] ) ^ beta )
+        if ( ( x[i] > -1 ) && ( x[i] < +1 ) ) {
+            y[i] <- ( ( 1 - x[i] ) ^ alpha ) * ( ( 1 + x[i] ) ^ beta )
+        }    
     }
     return ( y )
 }
